@@ -9,9 +9,8 @@ This is the complete API reference:
 .. autosummary::
    :toctree: .
 
-   hub
 """
 
-__version__ = "0.5.2"  # denote a pre-release for 0.1.0 with 0.1a1
+__version__ = "0.6.0"  # denote a pre-release for 0.1.0 with 0.1a1
 
-from ._hub import get_hub_with_authentication, hub  # noqa
+from ._entities import Entities  # noqa
