@@ -16,7 +16,7 @@ def lint(session: nox.Session) -> None:
 def build(session):
     session.install(".[dev,test]")
     login_user_1 = "lndb login raspbear@gmx.de --password MmR4YuQEyb0yxu7dAwJZTjLzR1Az2lN4Q4IduDlO"  # noqa
-    create_instance_1 = "lndb init --storage mydata --schema bionty,wetlab"  # noqa
+    create_instance_1 = "lndb init --storage mydata --schema bionty,wetlab,bfx"  # noqa
     session.run(*(login_user_1.split(" ")))
     session.run(*(create_instance_1.split(" ")))
     session.run(
